Create settings for generating prompts

createPromptSettings(maxDays = 20, legacy = FALSE)

Arguments

maxDays

How many days can a single code have? For example, if maxDays = 5 and there is a measurement code that appears on more than 5 days, a random sample of 5 days will be taken. Set to 0 if there is no maximum.

legacy

IF TRUE, will use the prompt from the Nature Digital Medicine paper.

Value

A settings object, to be used in reviewCases().