R/SensitiveCohort.R
createReferenceCohortTableNames.Rd
Derives a metadata table name from the reference cohort table name in a systematic way.
createReferenceCohortTableNames(referenceCohortTable)
The name of the cohort table itself. The metadata table name will be derived from this by appending '_metadata'.
A list with referenceCohortTable and referenceCohortMetadataTable.
referenceCohortTable
referenceCohortMetadataTable