Creates a cohort that is highly sensitive. Nobody outside the cohort is expected to have the disease. As a consequence, specificity inside the cohort is likely low.

This cohort can be used to determine the sensitivity of a cohort definition.

The cohort is constructed by combining two sets:

  1. Anybody who has one of the condition concepts of the disease of interest, indexed on the first occurrence.

  2. Anybody who has 'highly specific concepts' from at least two Keeper categories (symptoms, drugs, etc.), indexed on the first occurrence.

Highly specific concepts are concepts where at least 10% of those who have that concept also have a condition concept for the disease of interest.

createSensitiveCohort(
  connectionDetails = NULL,
  connection = NULL,
  cdmDatabaseSchema,
  tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
  cohortDatabaseSchema,
  cohortTable,
  createCohortTable = FALSE,
  cohortDefinitionId,
  keeperConceptSets
)

Arguments

connectionDetails

An R object of type connectionDetails created using the DatabaseConnector::createConnectionDetails() function. Not required of connection is provided.

connection

The connection to the database server created using DatabaseConnector::connect(). Not required if connectionDetails is provided.

cdmDatabaseSchema

The name of the database schema that contains the OMOP CDM instance. Requires read permissions to this database. On SQL Server, this should specify both the database and the schema, so for example 'cdm_instance.dbo'.

tempEmulationSchema

Some database platforms like Oracle and Impala do not truly support temp tables. To emulate temp tables, provide a schema with write privileges where temp tables can be created.

cohortDatabaseSchema

The name of the database schema that is the location where the cohort will be stored.

cohortTable

The table name where the cohort will be stored.

createCohortTable

Create the cohort table. If TRUE and the table already exists it will first be deleted.

cohortDefinitionId

The cohort definition ID that will be used for the cohort.

keeperConceptSets

A data frame with Keeper concept sets as generated by generateKeeperConceptSets().

Value

This function is primarily executed for instantiating the cohort in the cohort table. It does return a data frame listing the concepts that were used to create the cohort.