Generate the concept sets used as input for Keeper. This function uses LLMs, the OHDSI vocabulary vector store, and Phoebe to populate concept sets for the disease of interest, symptoms, treatments etc. of the given medical condition.

generateKeeperConceptSets(
  phenotype,
  client,
  vocabConnectionDetails,
  vocabDatabaseSchema
)

Arguments

phenotype

A text string denoting the condition of interest, e.g. 'Type I Diabetes Mellitus (T1DM)'. This string is used as input for the LLM.

client

An LLM client created using the ellmer package.

vocabConnectionDetails

Connection details for a database server hosting the OHDSI Vocabulary. Should be created using the createConnectionDetails function in the DatabaseConnector package.

vocabDatabaseSchema

The name of the database schema on the server where the vocabulary tables are located.

Value

A data frame with the following columns:

  • conceptId

  • conceptName

  • vocabularyId

  • conceptSetName: 'doi', 'symptoms', ...

  • target: 'Disease of interest' or 'Alternative diagnoses'.