Launch the reviewer Shiny app

launchReviewerApp(keeper, keeperConceptSets, decisionsFileName)

Arguments

keeper

The output of the generateKeeper() function.

keeperConceptSets

The output of the generateKeeperConceptSets() function.

decisionsFileName

The location of the CSV file where the decisions made by the reviewer will be written. If the file doesn't exist it will be created. If it does exist, it will be loaded and can be edited in the Shiny app.

Value

Returns nothing. Called for launching the Shiny app.