Review Keeper profiles using an LLM
reviewCases(
keeper,
settings = createPromptSettings(),
phenotypeName = NULL,
client,
cacheFolder
)Output from the generateKeeper() function.
Prompt creating settings as created using the createPromptSettings function.
The name of the disease to use in the prompt. If not provided, the name in the Keeper input will be used.
An LLM client created using the ellmer package.
A folder where the LLM responses are cached. If the process terminates for some reason, it can pick up where it left off using the cache.
A tibble with these columns:
generatedId
isCase, with possible values "yes" or "no",
certainty, certainty of the LLM in its decision, can be "high" or "low".
justification, written by the LLM.
cohortPrevalence, prevalence of the cohort in the entire population.
model, the LMM used to review.
keeperVersion, the version of the Keeper package.
When the Keeper profiles were generated with removePii = FALSE, the following columns are also included:
personId
cohortStartDate